@@ -106,6 +106,9 @@ KeyEntry key_list[] =
     {I18N_NOOP("Half katakana mode"),           "_IMEngine_Anthy_HalfKatakanaModeKey",
      I18N_NOOP("The key events to switch input mode to half katakana. "),
      ModeKeys},
+    {I18N_NOOP("Pseudo ASCII mode cancel"),     "_IMEngine_Anthy_CancelPseudoAsciiModeKey",
+     I18N_NOOP("The key events to cancel the pseudo ASCII mode. "),
+     ModeKeys},
     {I18N_NOOP("Circle typing method"),         "_IMEngine_Anthy_CircleTypingMethodKey",
      I18N_NOOP("The key events to circle typing method. "),
      ModeKeys},
@@ -1442,7 +1445,6 @@ void ScimAnthySettingPlugin::customize_nicola_table ()
     connect (editor->m_table_chooser_combo,
              SIGNAL (activated (int)),
              this, SLOT (set_thumb_shift_table_view ()));
-    editor->show ();
 
 #if 0
     // Don't use QDialog::exec() because toolbar of SKIM is freezed when use it.
@@ -1474,6 +1476,9 @@ void ScimAnthySettingPlugin::customize_nicola_table ()
     slotWidgetModified ();
 
     d->m_table_editor = NULL;
+#else
+    editor->setDestructive (true);
+    editor->show ();
 #endif
 }
 
